OutOfMemory

Struct OutOfMemory 

pub struct OutOfMemory { /* private fields */ }
Out-of-memory error.

This error is the sentinel for allocation failure due to memory exhaustion.

Constructing an Error from an OutOfMemory does not allocate.

Allocation failure inside any Error method that must allocate (e.g. Error::context) will propagate an OutOfMemory error.

Implementations

Source

impl OutOfMemory

pub const fn new() -> Self

Construct a new OutOfMemory error.

This operation does not allocate.