pub struct OutOfMemory { /* private fields */ }Expand description
Out-of-memory error.
This error is the sentinel for allocation failure due to memory exhaustion.
Constructing an Error from an OutOfMemory does not
allocate.
Allocation failure inside any Error method that must allocate
(e.g. Error::context) will propagate an
OutOfMemory error.
Implementations
Sourceimpl OutOfMemory
impl OutOfMemory